## Please DON'T install the version 5.24.12.8 because the description still describes the version 3.* .

#### New changes

(1) Fixed the description.

(2) Supported 3.12 & Nonsupported 2.*,3.6,3.7,3.8,3.9.